<?php
/*
Plugin Name: Kau-Boy's AutoCompleter
Plugin URI: http://www.kau-boys.de/autocompleter/
Description: Kau-Boy's AutoCompleter
Version: 1.3.5
Author: Bernhard Kau
Author URI: http://www.kau-boys.de
*/


define('AUTOCOMPLETER_URL', WP_PLUGIN_URL.'/'.str_replace(basename( __FILE__),"",plugin_basename(__FILE__)));
define('AUTOCOMPLETER_SEARCHFIELD_ID', get_option('kau-boys_autocompleter_id'));

function init_autocompleter() {
	load_plugin_textdomain('autocompleter', false, dirname(plugin_basename(__FILE__)));

	$custom_css = get_option('kau-boys_autocompleter_custom_css');
	$framework = get_option('kau-boys_autocompleter_framework');

	if($framework == 'scriptaculous'){
		wp_enqueue_script('autocomplete', AUTOCOMPLETER_URL.'autocompleter.js.php', array('scriptaculous'));
	} else {
		wp_enqueue_script('autocomplete', AUTOCOMPLETER_URL.'autocompleter.js.php', array('suggest'));
	}
	wp_enqueue_style('autocomplete', (empty($custom_css)? AUTOCOMPLETER_URL.'autocompleter.css' : $custom_css), null, null, 'screen');
}

function autocompleter_admin_menu(){
	add_options_page("Kau-Boy's AutoCompleter settings", 'AutoCompleter', 8, __FILE__, 'autocompleter_admin_settings');	
}

function autocompleter_filter_plugin_actions($links, $file){
	static $this_plugin;
	if (!$this_plugin) $this_plugin = plugin_basename(__FILE__);
	
	if ($file == $this_plugin){
		$settings_link = '<a href="options-general.php?page=kau-boys-autocompleter/autocompleter.php">'.__('Settings').'</a>';
		array_unshift($links, $settings_link);
	}
	return $links;
}

function autocompleter_admin_settings(){
	if(isset($_POST['save'])){	
		update_option('kau-boys_autocompleter_framework', $_POST['kau-boys_autocompleter_framework']);
		update_option('kau-boys_autocompleter_id', $_POST['kau-boys_autocompleter_id']);
		update_option('kau-boys_autocompleter_choices', $_POST['kau-boys_autocompleter_choices']);
		update_option('kau-boys_autocompleter_custom_css', $_POST['kau-boys_autocompleter_custom_css']);
		$settings_saved = true;
	}
	$framework = get_option('kau-boys_autocompleter_framework');
	$searchfield_id = get_option('kau-boys_autocompleter_id');
	$choices = get_option('kau-boys_autocompleter_choices');
	$custom_css = get_option('kau-boys_autocompleter_custom_css');
	
	// set default if values haven't been recieved from the database
	if(empty($searchfield_id)) $searchfield_id = 's';
	if(empty($choices)) $choices = 10;
?>

<div class="wrap">
<h2>Kau-Boy's AutoCompleter</h2>
<? if($settings_saved) : ?>
<div id="message" class="updated fade"><p><?php _e('Saved changes') ?>.</p></div>
<? endif ?>
<p>
	<?php _e('Here you can customize the plugin for your needs.', 'autocompleter') ?>
</p>
<form method="post" action="">
	<p>
		<label for="kau-boys_autocompleter_framework" style="width: 200px; display: inline-block;"><?php _e('Search field ID', 'autocompleter') ?></label>
		<select id="kau-boys_autocompleter_framework" name="kau-boys_autocompleter_framework" style="width: 147px;">
			<option<?php echo ($framework == 'jQuery')? ' selected="selected"' : '' ?>>jQuery</option>
			<option<?php echo ($framework == 'scriptaculous')? ' selected="selected"' : '' ?>>scriptaculous</option>
		</select>
		<span class="setting-description"><?php _e('Here you can choose the JavaScript framework you prefer.', 'autocompleter') ?></span>
	</p> 
	<p>
		<label for="kau-boys_autocompleter_id" style="width: 200px; display: inline-block;"><?php _e('Search field ID', 'autocompleter') ?></label>
		<input type="text" id="kau-boys_autocompleter_id" name="kau-boys_autocompleter_id" value="<?php echo $searchfield_id ?>" />
		<span class="setting-description"><?php _e('Here you can set the ID from the search input used in your template (default = s).', 'autocompleter') ?></span>
	</p> 
	<p>
		<label for="kau-boys_autocompleter_choices" style="width: 200px; display: inline-block;"><?php _e('Number of results', 'autocompleter') ?></label>
		<input type="text" id="kau-boys_autocompleter_choices" name="kau-boys_autocompleter_choices" value="<?php echo $choices ?>" />
		<span class="setting-description"><?php _e('Here you can set the number of posts that will be shown.', 'autocompleter') ?></span>
	</p>  
	<p>
		<label for="kau-boys_autocompleter_custom_css" style="width: 200px; display: inline-block;"><?php _e('Path to custom css', 'autocompleter') ?></label>
		<input type="text" id="kau-boys_autocompleter_custom_css" name="kau-boys_autocompleter_custom_css" value="<?php echo $custom_css ?>" />
		<span class="setting-description"><?php _e('Here you can set the path to a custom css file. Just use the autocompleter.css from the plugin folder as an example to create your own stylessheets.', 'autocompleter') ?></span>
	</p>  
	<p class="submit">
		<input name="save" type="submit" value="<?php _e('Save Changes') ?>" />
	</p>
</form>

</div>

<?php
}
 
add_action('init', 'init_autocompleter');
add_action('admin_menu', 'autocompleter_admin_menu');
add_filter('plugin_action_links', 'autocompleter_filter_plugin_actions', 10, 2);

?>